*************
API reference
*************

This section documents the complete application programming interface (API) of Valmix. If you are new to Valmix, you may want to read the usage guide in the readme first.

Knobs
=====

.. automodule:: valmix.knob
    :members:

TUI
===

.. automodule:: valmix.app
    :members:

.. automodule:: valmix.knob_widget
    :members:
